@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable;
 
-our $DATE = '2020-02-23'; # DATE
-our $VERSION = '0.583'; # VERSION
+our $DATE = '2020-10-04'; # DATE
+our $VERSION = '0.584'; # VERSION
 
 use 5.010001;
 use strict;
@@ -116,6 +116,8 @@ sub _add_arg {
 }
 
 sub _gen_meta {
+    require Data::Sah::Resolve;
+
     my ($table_spec, $opts) = @_;
     my $langs = $opts->{langs};
 
@@ -272,7 +274,8 @@ _
     for my $fname (keys %{$table_spec->{fields}}) {
         my $fspec   = $table_spec->{fields}{$fname};
         my $fschema = $fspec->{schema};
-        my $ftype   = $fschema->[0];
+        my $frschema = Data::Sah::Resolve::resolve_schema($fschema);
+        my $ftype   = $frschema->[0];
 
         next unless $opts->{enable_filtering};
         next if defined($fspec->{filterable}) && !$fspec->{filterable};
@@ -1530,7 +1533,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.583 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2020-02-23.
+This document describes version 0.584 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2020-10-04.
 
 =head1 SYNOPSIS
 
@@ -1634,10 +1637,6 @@ paging. The resulting function can then be run via command-line using
 L<Perinci::CmdLine> (as demonstrated in Synopsis), or served via HTTP using
 L<Perinci::Access::HTTP::Server>, or consumed normally by Perl programs.
 
-=head1 CAVEATS
-
-It is often not a good idea to expose your database schema directly as API.
-
 =head1 FUNCTIONS
 
 
@@ -2031,6 +2030,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 CAVEATS
+
+It is often not a good idea to expose your database schema directly as API.
+
 =head1 SEE ALSO
 
 L<Perinci::Sub::Gen::AccessTable::Simple> for a simpler variant.
